
Task
====

In this handbook we go through some technical details of 
how the tasks works and how to change their behaviour.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   termination
   execution
   observer